@@ -6,6 +6,10 @@ import sys
 
 from shuttle.cli import click
 from shuttle.providers.bitcoin.htlc import HTLC
+from shuttle.providers.config import bitcoin
+
+# Bitcoin config
+bitcoin = bitcoin()
 
 
 @click.command("htlc", options_metavar="[OPTIONS]",
@@ -13,7 +17,8 @@ from shuttle.providers.bitcoin.htlc import HTLC
 @click.option("-sh", "--secret-hash", type=str, required=True, help="Set secret 256 hash.")
 @click.option("-ra", "--recipient-address", type=str, required=True, help="Set Bitcoin recipient address.")
 @click.option("-sa", "--sender-address", type=str, required=True, help="Set Bitcoin sender address.")
-@click.option("-s", "--sequence", type=int, default=100, help="Set Bitcoin expiration block (sequence).")
+@click.option("-sq", "--sequence", type=int, default=bitcoin["sequence"],
+              help="Set Bitcoin sequence/expiration block.")
 @click.option("-n", "--network", type=str, default="testnet", help="Set Bitcoin network.")
 def htlc(secret_hash, recipient_address, sender_address, sequence, network):
     try:
